pub struct BinaryCacheStore { /* private fields */ }Expand description
A read-only binary cache store accessed over HTTP.
Implementations
Sourceimpl BinaryCacheStore
impl BinaryCacheStore
Sourcepub fn builder(base_url: &str) -> BinaryCacheStoreBuilder
pub fn builder(base_url: &str) -> BinaryCacheStoreBuilder
Create a builder for a binary cache store with the given base URL.
Sourcepub fn new(base_url: &str, trusted_keys: Vec<String>) -> Self
pub fn new(base_url: &str, trusted_keys: Vec<String>) -> Self
Create a new binary cache client with default HTTP backend.
Sourcepub fn with_http_client(
base_url: &str,
trusted_keys: Vec<String>,
client: Box<dyn HttpClient>,
) -> Self
pub fn with_http_client( base_url: &str, trusted_keys: Vec<String>, client: Box<dyn HttpClient>, ) -> Self
Create a new binary cache client with a custom HTTP backend.
Sourcepub async fn fetch_narinfo(&self, hash: &str) -> StoreResult<Option<NarInfo>>
pub async fn fetch_narinfo(&self, hash: &str) -> StoreResult<Option<NarInfo>>
Fetch NarInfo for a store path hash.
Sourcepub fn base_url(&self) -> &str
pub fn base_url(&self) -> &str
Return the base URL of this binary cache (without trailing slash).
Sourcepub fn trusted_keys(&self) -> &[String]
pub fn trusted_keys(&self) -> &[String]
Return the trusted public keys used for signature verification.
Sourcepub fn auth_header(&self) -> Option<(&str, &str)>
pub fn auth_header(&self) -> Option<(&str, &str)>
Return the configured authorization header, if any.
Sourcepub async fn fetch_nar(&self, url_path: &str) -> StoreResult<Vec<u8>>
pub async fn fetch_nar(&self, url_path: &str) -> StoreResult<Vec<u8>>
Download a NAR file from the cache.
Sourcepub fn verify_narinfo_signatures(
narinfo: &NarInfo,
trusted_keys: &[String],
) -> StoreResult<bool>
pub fn verify_narinfo_signatures( narinfo: &NarInfo, trusted_keys: &[String], ) -> StoreResult<bool>
Verify that a NarInfo has at least one valid signature from the trusted keys.
The NarInfo fingerprint is: 1;{storePath};{narHash};{narSize};{sortedReferences}.
Each signature in the NarInfo is in keyname:base64sig format. Each trusted key
is in keyname:base64pubkey format.
Returns Ok(true) if at least one signature matches a trusted key,
Ok(false) if no trusted keys are provided or no signatures match.